@@ -3,6 +3,7 @@ package resources
 import (
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/cloudtrail"
+	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
 )
 
 func init() {
@@ -39,6 +40,11 @@ func (trail *CloudTrailTrail) Remove() error {
 	return err
 }
 
+func (trail *CloudTrailTrail) Properties() types.Properties {
+	return types.NewProperties().
+		Set("Name", trail.name)
+}
+
 func (trail *CloudTrailTrail) String() string {
 	return *trail.name
 }
