@@ -10,6 +10,7 @@ import (
 type CloudWatchAlarm struct {
 	svc       *cloudwatch.CloudWatch
 	alarmName *string
+	tags      []*cloudwatch.Tag
 }
 
 func init() {
@@ -31,9 +32,14 @@ func ListCloudWatchAlarms(sess *session.Session) ([]Resource, error) {
 		}
 
 		for _, metricAlarm := range output.MetricAlarms {
+			tags, err := GetAlarmTags(svc, metricAlarm.AlarmArn)
+			if err != nil {
+				return nil, err
+			}
 			resources = append(resources, &CloudWatchAlarm{
 				svc:       svc,
 				alarmName: metricAlarm.AlarmName,
+				tags:      tags,
 			})
 		}
 
@@ -47,6 +53,15 @@ func ListCloudWatchAlarms(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
+func GetAlarmTags(svc *cloudwatch.CloudWatch, arn *string) ([]*cloudwatch.Tag, error) {
+	resp, err := svc.ListTagsForResource(&cloudwatch.ListTagsForResourceInput{ResourceARN: arn})
+	if err != nil {
+		return nil, err
+	}
+
+	return resp.Tags, nil
+}
+
 func (f *CloudWatchAlarm) Remove() error {
 
 	_, err := f.svc.DeleteAlarms(&cloudwatch.DeleteAlarmsInput{
@@ -57,8 +72,13 @@ func (f *CloudWatchAlarm) Remove() error {
 }
 
 func (f *CloudWatchAlarm) Properties() types.Properties {
-	return types.NewProperties().
-		Set("Name", f.alarmName)
+	properties := types.NewProperties()
+	properties.Set("Name", f.alarmName)
+
+	for _, tag := range f.tags {
+		properties.SetTag(tag.Key, tag.Value)
+	}
+	return properties
 }
 
 func (f *CloudWatchAlarm) String() string {
